==> twig-0.7.0.tgz: package/docs/wiki/Implementation-Notes.md <==
# Differences / Implementation Notes

 - currently twig.js does not have the same auto-escaping that Twig does. 
 - Macros are not yet supported

## Feature Support

Built-in Tags:

 - `autoescape`: 
 - `block`: **Supported**
 - `do`: 
 - `extends`: **Supported**
 - `filter`: **Supported**
 - `flush`: N/A
 - `for`: **Supported**
 - `from`: 
 - `if`: **Supported**
 - `import`: 
 - `include`: **Supported**
 - `macro`: 
 - `raw`: 
 - `sandbox`: 
 - `set`: **Supported**
 - `spaceless`: 
 - `use`: **Supported**

Built-in Filters:

 - `capitalize`: **Supported**
 - `convert_encoding`: 
 - `date`: **Supported**
 - `default`: **Supported**
 - `escape`: **Supported**
 - `format`: **Supported**
 - `join`: **Supported**
 - `json_encode`: **Supported**
 - `keys`: **Supported**
 - `length`: **Supported**
 - `lower`: **Supported**
 - `merge`: **Supported**
 - `nl2br`: **Supported**
 - `number_format`: **Supported**
 - `raw`: 
 - `replace`: **Supported**
 - `reverse`: **Supported**
 - `slice`: 
 - `sort`: **Supported**
 - `striptags`: **Supported**
 - `title`: **Supported**
 - `trim`: **Supported**
 - `upper`: **Supported**
 - `url_encode`: **Supported**

Built-in Functions:
 - `attribute`: 
 - `block`: 
 - `constant`: 
 - `cycle`: **Supported**
 - `date`: **Supported**
 - `dump`: **Supported**
 - `parent`: **Supported**
 - `random`: 
 - `range`: **Supported**
    
Built-in Tests: 

 - `constant`: 
 - `defined`: **Supported**
 - `divisibleby`: **Supported**
 - `empty`: **Supported**
 - `even`: **Supported**
 - `iterable`: 
 - `null` / `none`: **Supported**
 - `odd`: **Supported**
 - `sameas`: **Supported**
    
Built-in Operators: 

 - `in`: **Supported**
 - `is`: **Supported**
 - Math (`+`, `-`, `/`, `%`, `*`, `**`): **Supported**
 - Logic (`and`, `or`, `not`, `()`): **Supported**
 - Comparisons (`==`, `!=`, `<`, `>`, `>=`, `<=`, `===`): **Supported**
 - Others (`..`, `|`, `~`, `.`, `[]`, `?:`): **Supported**

==> twig-0.8.7.tgz: package/docs/wiki/Implementation-Notes.md <==
# Differences / Implementation Notes

 - currently twig.js does not have the same auto-escaping that Twig does.

## Feature Support

Built-in Tags:

 - `autoescape`: 
 - `block`: **Supported**
 - `do`: 
 - `extends`: **Supported**
 - `filter`: **Supported**
 - `flush`: N/A
 - `for`: **Supported**
 - `from`: **Supported**
 - `if`: **Supported**
 - `import`: **Supported**
 - `include`: **Supported**
 - `macro`: **Supported**
 - `raw`: 
 - `sandbox`: 
 - `set`: **Supported**
 - `spaceless`: **Supported**
 - `use`: **Supported**

Built-in Filters:

 - `abs`: **Supported**
 - `batch`: **Supported**
 - `capitalize`: **Supported**
 - `convert_encoding`: N/A
 - `date`: **Supported**
 - `date_modify`: **Supported**
 - `default`: **Supported**
 - `escape`: **Supported**
 - `first`: **Supported**
 - `format`: **Supported**
 - `join`: **Supported**
 - `json_encode`: **Supported**
 - `keys`: **Supported**
 - `last`: **Supported**
 - `length`: **Supported**
 - `lower`: **Supported**
 - `merge`: **Supported**
 - `nl2br`: **Supported**
 - `number_format`: **Supported**
 - `merge`: **Supported**
 - `raw`: 
 - `replace`: **Supported**
 - `reverse`: **Supported**
 - `round`: **Supported**
 - `slice`: **Supported**
 - `sort`: **Supported**
 - `split`: **Supported**
 - `striptags`: **Supported**
 - `title`: **Supported**
 - `trim`: **Supported**
 - `upper`: **Supported**
 - `url_encode`: **Supported**

Built-in Functions:
 - `attribute`: **Supported**
 - `block`: **Supported**
 - `constant`: 
 - `cycle`: **Supported**
 - `date`: **Supported**
 - `dump`: **Supported**
 - `include`: 
 - `max`: Open Pull Request #164 
 - `min`: Open Pull Request #164 
 - `parent`: **Supported**
 - `random`: **Supported**
 - `range`: **Supported**
 - `source`: 
    
Built-in Tests: 

 - `constant`: 
 - `defined`: **Supported**
 - `divisibleby`: **Supported**
 - `empty`: **Supported**
 - `even`: **Supported**
 - `iterable`: Open Pull Request #165 
 - `null` / `none`: **Supported**
 - `odd`: **Supported**
 - `sameas`: **Supported**
    
Built-in Operators: 

 - `in`: **Supported**
 - `is`: **Supported**
 - Math (`+`, `-`, `/`, `%`, `*`, `**`): **Supported**
 - Logic (`and`, `or`, `not`, `()`): **Supported**
 - Comparisons (`==`, `!=`, `<`, `>`, `>=`, `<=`, `===`): **Supported**
 - Others (`..`, `|`, `~`, `.`, `[]`, `?:`): **Supported**
